<?xml version='1.0' encoding='UTF-8'?>

<xsl:stylesheet version='1.0' xmlns:xsl='http://www.w3.org/1999/XSL/Transform'>

<xsl:output method='html' indent='yes'/>

<xsl:param name="Lang" select="'en_GB'"/>
<xsl:variable name="StringFile" select="document('strings.xml')"/>
<xsl:variable name="PrimaryLang" select="substring-before($Lang,'_')"/>


<xsl:template name="getString">
  <xsl:param name="stringName"/>
  <xsl:variable name="str" select="$StringFile/strings/str[@name=$stringName]"/>
  <xsl:choose>
    <xsl:when test="$str[lang($Lang)]">
      <xsl:value-of select="$str[lang($Lang)][1]"/>
    </xsl:when>
    <xsl:when test="$str[lang($PrimaryLang)]">
      <xsl:value-of select="$str[lang($PrimaryLang)][1]"/>
    </xsl:when>
    <xsl:when test="$str">
      <xsl:value-of select="$str[1]"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:message terminate="no">
        <xsl:text>Warning: no string named '</xsl:text>
        <xsl:value-of select="$stringName"/>
        <xsl:text>' found.</xsl:text>
      </xsl:message>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>





<xsl:template match='/palette'>
  <HTML>
   <HEAD>
    <TITLE>
    	<xsl:call-template name='getString'>
    		<xsl:with-param name="stringName">title1</xsl:with-param>
  		</xsl:call-template>
    </TITLE>
    <META http-equiv="content-type" content="text-html; charset=utf-8"></META>
   </HEAD>
   <BODY>
	<H1><xsl:value-of select='@name'/> 
	   	<xsl:call-template name='getString'>
    		<xsl:with-param name="stringName">palette</xsl:with-param>
  		</xsl:call-template>
	</H1>
    <xsl:if test="@description!=''">
    <xsl:value-of select='@description'/>
    </xsl:if>
    <H2>
    	<xsl:call-template name='getString'>
    		<xsl:with-param name="stringName">title2</xsl:with-param>
  		</xsl:call-template>
    </H2>	    
    	<TABLE BORDER="0">
    		<xsl:call-template name='summary'/>
    	</TABLE>
    	<HR/>
    	<xsl:call-template name='detail'/>
    </BODY>
  </HTML>
 </xsl:template>
 

<xsl:template match='/paletteobjects'>
  <HTML>
   <HEAD>
    <TITLE>
    	<xsl:call-template name='getString'>
    		<xsl:with-param name="stringName">title3</xsl:with-param>
  		</xsl:call-template>
    </TITLE>
    <META http-equiv="content-type" content="text-html; charset=utf-8"></META>
   </HEAD>
   <BODY>
    <H2>
    	<xsl:call-template name='getString'>
    		<xsl:with-param name="stringName">title2</xsl:with-param>
  		</xsl:call-template>
	</H2>	    
    	<TABLE BORDER="0">
    		<xsl:call-template name='summary'/>
    	</TABLE>
    	<HR/>
    	<xsl:call-template name='detail'/>
    </BODY>
  </HTML>
 </xsl:template>


<xsl:template name='summary'>
	<xsl:apply-templates mode="summary"/>
</xsl:template>   

<xsl:template match='category' mode="summary">
	<TR>
		<TD><H3><xsl:value-of select='@id'/></H3></TD>
	</TR>
	<xsl:apply-templates mode="summary"/>
</xsl:template>     

<xsl:template match='symbol' mode="summary">
	<TR>
		<TD>
			<img width="24" height="24"><xsl:attribute name='src'>images/<xsl:value-of select='@icon'/></xsl:attribute></img>
		</TD>
		<TD >
			<A>
		     <xsl:attribute name='href'>#<xsl:value-of select='@id'/></xsl:attribute>
		     <xsl:value-of select='@id'/>
		    </A>
    	</TD>
    </TR>
</xsl:template>   



  
<xsl:template name='detail'>
	<xsl:apply-templates mode="detail"/>
</xsl:template>
 
<xsl:template match='category' mode="detail">
	<H3><xsl:value-of select='@id'/></H3>
	<xsl:apply-templates mode="detail"/>
</xsl:template> 

<xsl:template match='symbol' mode="detail">
	<A>
     <xsl:attribute name='name'><xsl:value-of select='@id'/></xsl:attribute>
    </A>
	<TABLE BORDER='0'>
		<TR>
			<TD>
				<img><xsl:attribute name='src'>images/<xsl:value-of select='@icon'/></xsl:attribute></img>
			</TD>
			<TD>
			     <xsl:value-of select='@id'/>
			</TD>
		</TR>
		
		<xsl:if test="@version!=''">
		<TR>
			<TD></TD>
			<TD>v<xsl:value-of select='@version'/></TD>
		</TR>
		</xsl:if>
		
		<xsl:if test="@shortdescription!=''">
		<TR>
			<TD></TD>
			<TD><xsl:value-of select='@shortdescription'/></TD>
		</TR>
		</xsl:if>
		
		<xsl:if test="@longdescription!=''">
		<TR>
			<TD></TD>
			<TD><xsl:value-of select='@longdescription'/></TD>
		</TR>
		</xsl:if>
		
		<TR>
			<TD></TD>
			<TD>
		    	<xsl:call-template name='getString'>
		    		<xsl:with-param name="stringName">parameters</xsl:with-param>
		  		</xsl:call-template>
			</TD>
		</TR>
		
		<TR>
			<TD></TD>
			<TD><xsl:call-template name='parameter_table'/></TD>
		</TR>
		
	</TABLE>

</xsl:template> 


 <xsl:template name='parameter_table'>
   <TABLE BORDER='1'>
   <TH ALIGN='LELFT'>
		    	<xsl:call-template name='getString'>
		    		<xsl:with-param name="stringName">id</xsl:with-param>
		  		</xsl:call-template>
   </TH>
   <TH ALIGN='LELFT'>
		    	<xsl:call-template name='getString'>
		    		<xsl:with-param name="stringName">description</xsl:with-param>
		  		</xsl:call-template>
   
   </TH>
   <TH ALIGN='LELFT'>
		    	<xsl:call-template name='getString'>
		    		<xsl:with-param name="stringName">type</xsl:with-param>
		  		</xsl:call-template>
   </TH>
   <TH ALIGN='LELFT'>
		    	<xsl:call-template name='getString'>
		    		<xsl:with-param name="stringName">value</xsl:with-param>
		  		</xsl:call-template>
   </TH>   
   <xsl:for-each select='child::parameter'>
       <TR>
         <TD><xsl:value-of select='@id'/></TD>
         <TD><xsl:value-of select='@shortdescription'/></TD>
         <TD><xsl:value-of select='@type'/></TD>
         <TD><xsl:value-of select='@value'/></TD>
       </TR>
   </xsl:for-each>
   </TABLE>
   <BR/>
 </xsl:template>

 
 
</xsl:stylesheet>
